pub enum ScrapeFormats {
Markdown,
HTML,
RawHTML,
Links,
Screenshot,
ScreenshotFullPage,
Extract,
}Variants
Markdown
Will result in a copy of the Markdown content of the page.
HTML
Will result in a copy of the filtered, content-only HTML of the page.
RawHTML
Will result in a copy of the raw HTML of the page.
Links
Will result in a Vec of URLs found on the page.
Screenshot
Will result in a URL to a screenshot of the page.
Can not be used in conjunction with ScrapeFormats::ScreenshotFullPage.
ScreenshotFullPage
Will result in a URL to a full-page screenshot of the page.
Can not be used in conjunction with ScrapeFormats::Screenshot.
Extract
Will result in the results of an LLM extraction.
See ScrapeOptions.extract for more options.