pub struct SpideryApp { /* private fields */ }Implementations
Sourceimpl SpideryApp
impl SpideryApp
Sourcepub async fn crawl_url_async(
&self,
url: impl AsRef<str>,
options: Option<CrawlOptions>,
) -> Result<CrawlAsyncResponse, SpideryError>
pub async fn crawl_url_async( &self, url: impl AsRef<str>, options: Option<CrawlOptions>, ) -> Result<CrawlAsyncResponse, SpideryError>
Initiates a crawl job for a URL using the Spidery API.
Sourcepub async fn crawl_url(
&self,
url: impl AsRef<str>,
options: impl Into<Option<CrawlOptions>>,
) -> Result<CrawlStatus, SpideryError>
pub async fn crawl_url( &self, url: impl AsRef<str>, options: impl Into<Option<CrawlOptions>>, ) -> Result<CrawlStatus, SpideryError>
Performs a crawl job for a URL using the Spidery API, waiting for the end result. This may take a long time depending on the size of the target page and your options (namely CrawlOptions.limit).
Sourcepub async fn check_crawl_status(
&self,
id: impl AsRef<str>,
) -> Result<CrawlStatus, SpideryError>
pub async fn check_crawl_status( &self, id: impl AsRef<str>, ) -> Result<CrawlStatus, SpideryError>
Checks for the status of a crawl, based on the crawl’s ID. To be used in conjunction with SpideryApp::crawl_url_async.
Sourceimpl SpideryApp
impl SpideryApp
Sourceimpl SpideryApp
impl SpideryApp
Sourcepub async fn scrape_url(
&self,
url: impl AsRef<str>,
options: impl Into<Option<ScrapeOptions>>,
) -> Result<Document, SpideryError>
pub async fn scrape_url( &self, url: impl AsRef<str>, options: impl Into<Option<ScrapeOptions>>, ) -> Result<Document, SpideryError>
Scrapes a URL using the Spidery API.
Sourceimpl SpideryApp
impl SpideryApp
pub fn new(api_key: impl AsRef<str>) -> Result<Self, SpideryError>
pub fn new_selfhosted( api_url: impl AsRef<str>, api_key: Option<impl AsRef<str>>, ) -> Result<Self, SpideryError>